@@ -7,10 +7,9 @@ OC.L10N.register(
     "Copy to full name" : "انسخ إلى الإسم الكامل",
     "Add contacts" : "اضافة جهات اتصال",
     "Loading …" : "جاري التحميل …",
+    "General settings" : "الإعدادات العامة",
     "Download" : "تحميل",
     "Send email" : "إرسال بريد",
-    "Groups" : "مجموعات",
-    "Group name" : "إسم الفريق",
     "Circles" : "جماعة",
     "Rename" : "تعديل الإسم",
     "Enabled" : "مفعلة",
