@@ -6,10 +6,9 @@ OC.L10N.register(
     "Contacts" : "Contautos",
     "Loading contacts …" : "Cargando contautos....",
     "Loading …" : "Cargando...",
+    "General settings" : "Axustes xenerales",
     "Download" : "Baxar",
     "Send email" : "Unviar mensaxe",
-    "Groups" : "Grupos",
-    "Group name" : "Nome del grupu",
     "Circles" : "Círculos",
     "Rename" : "Renomar",
     "Enabled" : "Habilitar",
