@@ -3,23 +3,34 @@ OC.L10N.register(
     {
     "Contacts" : "Kontakti",
     "Download" : "Preuzmi",
-    "Groups" : "Grupe",
-    "Group name" : "Naziv grupe",
+    "Send email" : "Pošalji e-poštu",
     "Rename" : "Preimenuj",
     "Enabled" : "Aktivirano",
     "Delete" : "Obriši",
     "can edit" : "mogu mijenjati",
     "First name" : "Ime",
     "Last name" : "Prezime",
+    "Password protection" : "Password protection",
+    "Save" : "Spremi",
+    "Description" : "Opis",
     "Invalid image" : "Nevažeća datoteka",
     "Name" : "Ime",
     "Title" : "Naslov",
     "Cancel" : "Otkaži",
     "New contact" : "Novi kontakt",
+    "Personal circle" : "Osobni krug",
+    "Pending" : "Na čekanju",
     "Close" : "Zatvori",
     "Import" : "Uvoz",
     "Not grouped" : "Nije grupirano",
+    "Circle" : "Krug",
+    "User" : "User",
+    "Group" : "Grupa",
     "Email" : "E-pošta",
+    "Member" : "Član",
+    "Admin" : "Administrator",
+    "Owner" : "Vlasnik",
+    "Users" : "Korisnici",
     "Nickname" : "Nadimak",
     "Additional names" : "Dodatna imena",
     "Notes" : "Notes",
