@@ -5,8 +5,7 @@ OC.L10N.register(
     "All contacts" : "Semua kontak",
     "Contacts" : "Kontak",
     "Download" : "Unduh",
-    "Groups" : "Grup",
-    "Group name" : "Nama grup",
+    "Send email" : "Kirim surel",
     "Rename" : "Ubah nama",
     "Enabled" : "Diaktifkan",
     "Delete" : "Hapus",
@@ -18,16 +17,26 @@ OC.L10N.register(
     "Last name" : "Nama belakang",
     "Display name" : "Nama tampilan",
     "Last modified" : "Terakhir diubah",
+    "Password protection" : "Password protection",
+    "Save" : "Simpan",
+    "Description" : "Deskrisi",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
     "Title" : "Judul",
     "Cancel" : "Membatalkan",
     "New contact" : "Kontak baru",
+    "Search contacts …" : "Cari kontak ...",
     "No results" : "Tidak ada hasil",
+    "Pending" : "Tunggu",
     "Close" : "Tutup",
     "Import" : "Impor",
     "Not grouped" : "Tidak dikelompokkan",
+    "User" : "Pengguna",
+    "Group" : "Grup",
     "Email" : "Email",
+    "Admin" : "Admin",
+    "Owner" : "Owner",
+    "Users" : "Pengguna",
     "Nickname" : "Nama panggilan",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
