@@ -6,10 +6,9 @@ OC.L10N.register(
     "Contacts" : "კონტაქტები",
     "Loading contacts …" : "კონტაქტების ჩატვირთვა ...",
     "Delete circle" : "წრის გაუქმება",
+    "General settings" : "მთავარი პარამეტრები",
     "Download" : "ჩამოტვირთვა",
     "Send email" : "ელ-წერილის გაგზავნა",
-    "Groups" : "ჯგუფები",
-    "Group name" : "ჯგუფის სახელი",
     "Circles" : "წრეები",
     "Create a new circle" : "შექმენით წრე",
     "Rename" : "სახელის შეცვლა",
@@ -80,6 +79,7 @@ OC.L10N.register(
     "Voice" : "ხმა",
     "Car" : "მაქნანა",
     "Work pager" : "სამუშაო პეიჯერი",
+    "Manager" : "მენეჯერი",
     "Social network" : "სოციალური ქსელი",
     "Spouse" : "მეუღლე",
     "Child" : "შვილი",
@@ -91,7 +91,6 @@ OC.L10N.register(
     "Relative" : "ნათესავი",
     "Friend" : "მეგობარი",
     "Colleague" : "კოლეგა",
-    "Manager" : "მენეჯერი",
     "Assistant" : "ასისტენტი",
     "Gender" : "სქესი",
     "Female" : "მდედორობითი",
