@@ -23,11 +23,11 @@ OC.L10N.register(
     "Add member" : "회원 추가",
     "Leave circle" : "서클 떠나기",
     "Delete circle" : "서클 삭제",
+    "General settings" : "일반 설정",
+    "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
+    "(refreshed once per week)" : "(주 1회 새로고침)",
     "Download" : "다운로드",
     "Send email" : "이메일 보내기",
-    "Groups" : "그룹",
-    "Create a new group" : "새 그룹 생성",
-    "Group name" : "그룹 이름",
     "Circles" : "서클",
     "Create a new circle" : "새 서클 만들기",
     "Show all groups" : "모든 그룹 보이기",
@@ -65,8 +65,6 @@ OC.L10N.register(
     "Display name" : "표시 이름",
     "Last modified" : "수정한 날짜",
     "Sort by {sorting}" : "{sorting}(으)로 정렬",
-    "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
-    "(refreshed once per week)" : "(주 1회 새로고침)",
     "An error happened during the config change" : "변경 사항을 설정하는 중 오류 발생",
     "Password protection" : "암호 보호",
     "Save" : "저장",
@@ -109,7 +107,6 @@ OC.L10N.register(
     "Address book" : "주소록",
     "New contact" : "새 연락처",
     "Syntax error. Cannot open the contact." : "문법 오류입니다. 연락처를 열 수 없습니다.",
-    "The contact doesn't exists anymore on the server." : "이 연락처는 더 이상 서버에 존재하지 않습니다.",
     "Unable to retrieve the contact from the server, please check your network connection." : "연락처를 가져올 수 없습니다. 네트워크 연결을 확인하세요.",
     "An error occurred while trying to move the contact" : "연락처를 이동하는 중 오류 발생",
     "An error occurred while trying to copy the contact" : "연락처를 복사하는 중 오류 발생",
@@ -127,7 +124,6 @@ OC.L10N.register(
     "Local circle" : "로컬 서클",
     "Create circle" : "서클 만들기",
     "Loading members list …" : "회원 목록 불러오는 중 ...",
-    "There is no member in this circle" : "이 서클에는 회원이 없음",
     "Add members" : "회원 추가",
     "Show circle details" : "서클 자세히 보기",
     "Add to {circle}" : "{circle}에 추가",
@@ -190,7 +186,6 @@ OC.L10N.register(
     "Circle membership" : "서클 회원",
     "Prevent circle from being a member of another circle" : "이 서클이 다른 서클의 회원이 될 수 없음",
     "Users" : "사용자",
-    "Emails" : "이메일",
     "Nickname" : "별명",
     "Detailed name" : "자세한 이름",
     "Additional names" : "추가 이름",
@@ -225,6 +220,7 @@ OC.L10N.register(
     "Voice" : "음성 번호",
     "Car" : "카폰",
     "Work pager" : "직장 호출기",
+    "Manager" : "관리자",
     "Social network" : "소셜 네트워크",
     "Relationship to you" : "나와의 관계",
     "Spouse" : "배우자",
@@ -237,7 +233,6 @@ OC.L10N.register(
     "Relative" : "친척",
     "Friend" : "친구",
     "Colleague" : "동료",
-    "Manager" : "관리자",
     "Assistant" : "비서",
     "Related contacts" : "관련된 연락처",
     "Agent" : "에이전트",
