@@ -9,8 +9,6 @@ OC.L10N.register(
     "Add member" : "Гишүүн нэмэх",
     "Delete circle" : "бүлгийг устгах",
     "Download" : "Татаж авах",
-    "Groups" : "Багууд",
-    "Group name" : "Бүлгийн нэр",
     "Circles" : "Тойрог",
     "Create a new circle" : "шинэ бүлэг үүсгэх",
     "Rename" : "Нэр солих",
@@ -77,6 +75,7 @@ OC.L10N.register(
     "Fax" : "Факс",
     "Fax home" : "Гэрийн факс",
     "Fax work" : "Ажлын факс",
+    "Manager" : "Менежер",
     "Social network" : "Олон нийтийн сүлжээ",
     "Child" : "хүүхэд",
     "Mother" : "эх",
@@ -86,7 +85,6 @@ OC.L10N.register(
     "Sister" : "эгч",
     "Relative" : "Хамаарал",
     "Friend" : "Найз",
-    "Manager" : "Менежер",
     "Co-worker" : "Хамтран ажиллагч",
     "Gender" : "Хүйс",
     "Female" : "Эмэгтэй",
