@@ -24,8 +24,12 @@ OC.L10N.register(
     "Delete circle" : "Slett sirkel",
     "Contacts settings" : "Kontaktinnstillinger",
     "General settings" : "Generelle innstillinger",
+    "Address books" : "Adressebøker",
     "Download" : "Last ned",
     "Send email" : "Send e-post",
+    "Contact groups" : "Kontaktgrupper",
+    "Create a new contact group" : "Opprett en ny kontaktgruppe",
+    "Contact group name" : "Kontaktgruppenavn",
     "Circles" : "Sirkler",
     "Create a new circle" : "Opprett en ny sirkel",
     "Show all groups" : "Vis alle grupper",
@@ -34,20 +38,27 @@ OC.L10N.register(
     "Collapse circles" : "Kollapse sirkler",
     "This group already exists" : "Denne gruppen finnes allerede",
     "This circle already exists" : "Denne sirkelen finnes allerede",
-    "An error happened during the creation of the circle" : "En feil oppstod under opprettelse av sirkelen",
+    "An error happened during the creation of the circle" : "En feil oppsto under opprettelse av sirkelen",
     "Rename" : "Gi nytt navn",
     "Enabled" : "Aktiver",
     "Delete" : "Slett",
     "Copied" : "Kopiert",
     "Cannot copy" : "Kan ikke kopiere",
     "Copy link" : "Kopier lenke",
+    "Toggling of address book was not successful" : "Veksling av adressebok var ikke vellykket",
     "Delete {addressbook}?" : "Slette {addressbook}?",
+    "_Shared with {num} entity_::_Shared with {num} entities_" : ["Delt med {num} entitet","Delt med {num} entiteter"],
     "Share with users or groups" : "Del med brukere eller grupper",
     "No users or groups" : "Ingen brukere eller grupper",
     "can edit" : "kan redigere",
+    "Unable to delete the share" : "Kan ikke slette delingen",
+    "Unable to change permissions" : "Kan ikke endre tillatelser",
     "Import contacts" : "Importer kontakter",
+    "Import into the {addressbookName} address book" : "Importer til {addressbookName}-adresseboken",
     "Select local file" : "Velg lokal fil",
+    "Import from Files" : "Importer fra Filer",
     "Choose a vCard file to import" : "Velg en vCard-fil å importere",
+    "Add new address book" : "Legg til ny adressebok",
     "First name" : "Fornavn",
     "Last name" : "Etternavn",
     "Phonetic first name" : "Fonetisk fornavn",
@@ -55,11 +66,15 @@ OC.L10N.register(
     "Display name" : "Visningsnavn",
     "Last modified" : "Sist endret",
     "Sort by {sorting}" : "Sorter etter {sorting}",
+    "Oversees" : "Overvåker",
     "Password protection" : "Passordbeskyttelse",
     "Enforce password protection on files shared to this circle" : "Håndhev passordbeskyttelse på filer som deles med denne sirkelen",
+    "Unique password …" : "Unikt passord...",
     "Save" : "Lagre",
+    "Change unique password" : "Endre unikt passord",
     "Circle name" : "Sirkelnavn",
     "Circle owned by {owner}" : "Sirkel eid av {owner}",
+    "Request to join" : "Spør om å bli med",
     "Description" : "Beskrivelse",
     "There is no description for this circle" : "Det er ingen beskrivelse av denne sirkelen",
     "Enter a description for the circle" : "Gi en beskrivelse av denne sirkelen",
@@ -77,7 +92,10 @@ OC.L10N.register(
     "Name" : "Navn",
     "Company" : "Bedrift",
     "Title" : "Tittel",
+    "Clone contact" : "Dupliser kontakt",
     "Generate QR Code" : "Generer QR-kode",
+    "Pick an address book" : "Velg en adressebok",
+    "Select address book" : "Velg adressebok",
     "Cancel" : "Avbryt",
     "This contact is not yet synced. Edit it to save it to the server." : "Denne kontakt er enda ikke synkronisert. Rediger den for å lagre den på serveren.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "Kontakten er skrivebeskyttet. Du har ikke tillatelse til å redigere denne kontakten.",
@@ -99,7 +117,7 @@ OC.L10N.register(
     "Add members" : "Legg til medlemmer",
     "Show circle details" : "Vis sirkeldetaljer",
     "Add to {circle}" : "Legg til i {circle}",
-    "There was an issue adding members to the circle" : "Det oppstod et problem med å legge til medlemmer til denne sirkelen",
+    "There was an issue adding members to the circle" : "Det oppsto et problem med å legge til medlemmer til denne sirkelen",
     "Manage level" : "Håndtere nivå",
     "Remove member" : "Fjern medlem",
     "Pending" : "Venter",
@@ -132,6 +150,7 @@ OC.L10N.register(
     "Could not copy link to the clipboard." : "Kunne ikke kopiere lenke til utklippstavlen",
     "Not grouped" : "Ikke gruppert",
     "Recently contacted" : "Nylig kontaktet",
+    "Organization chart" : "Organisasjonskart",
     "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "Sirkeler lar deg opprette grupper med andre brukere på en Nextcloud-instans og dele med dem.",
     "Circle" : "Sirkel",
     "User" : "Bruker",
@@ -143,12 +162,15 @@ OC.L10N.register(
     "Admin" : "Administrator",
     "Owner" : "Eier",
     "Invites" : "Invitasjoner",
+    "Anyone can request membership" : "Alle kan be om medlemskap",
+    "Members need to accept invitation" : "Medlemmer må godta invitasjonen",
     "Members can also invite" : "Medlemmer kan også invitere",
     "Visibility" : "Synlighet",
     "Visible to everyone" : "Synlig for alle",
     "Circle membership" : "Sirkelmedlemskap",
     "Prevent circle from being a member of another circle" : "Hindre sirkel fra å kunne bli medlem av en annen sirkel",
     "Users" : "Brukere",
+    "Email addresses" : "E-postadresser",
     "Nickname" : "Kallenavn",
     "Detailed name" : "Detaljert navn",
     "Additional names" : "Ev. mellomnavn",
@@ -204,7 +226,7 @@ OC.L10N.register(
     "Male" : "Dame",
     "None" : "Ingen",
     "Unknown" : "Ukjent",
-    "Time zone" : "Tidsone",
+    "Time zone" : "Tidssone",
     "Spoken languages" : "Talte språk",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} kontakt kunne ikke bli lest inn","{failed} kontakter kunne ikke bli lest inn"],
     "Some circle(s) an error occurred. Check the console for more details." : "En feil har oppstått i en eller flere sirkeler. Sjekk konsollen for mer detaljer.",
