@@ -5,10 +5,9 @@ OC.L10N.register(
     "All contacts" : "Totes los contactes",
     "Contacts" : "Contactes",
     "Loading …" : "Cargament…",
+    "General settings" : "Paramètres generals",
     "Download" : "Telecargar",
     "Send email" : "Enviar email",
-    "Groups" : "Gropes",
-    "Group name" : "Nom del grop",
     "Circles" : "Cercles",
     "Rename" : "Renomenar",
     "Enabled" : "Activada",
