@@ -3,14 +3,19 @@ OC.L10N.register(
     {
     "Details" : "معلومات",
     "Download" : "ښکته کول",
-    "Groups" : "ګروپونه",
     "Rename" : "نوم بدلول",
     "Delete" : "ړنګول",
     "Copy link" : "لېنک کاپي کول",
+    "Save" : "ساتل",
     "Invalid image" : "انځور سم نه دی",
     "Name" : "نوم",
     "Cancel" : "پرېښول",
+    "Search contacts …" : "اړيکي پلټل ...",
+    "Pending" : "د انتظار په حال کې",
     "Close" : "بندول",
+    "Circle" : "حلقه",
+    "Admin" : "ستر کارن",
+    "Users" : "کارنان",
     "Notes" : "شسیب",
     "Home" : "کور",
     "Work" : "دفتر",
