@@ -4,9 +4,6 @@ OC.L10N.register(
     "Details" : "විස්තර",
     "Loading …" : "පූරණය වෙමින් …",
     "Download" : "බාගන්න",
-    "Groups" : "සමූහ…",
-    "Create a new group" : "නව සමූහයක් සාදන්න",
-    "Group name" : "සමූහයේ නම",
     "Rename" : "නැවත නම් කරන්න",
     "Enabled" : "සබල කර ඇත",
     "Copy link" : "සබැඳිය පිටපත් කරන්න",
