@@ -9,10 +9,9 @@ OC.L10N.register(
     "Omit year" : "Shmang vitin",
     "Loading contacts …" : "Duke ngarkuar kontaktet ...",
     "Delete circle" : "Fshini rrethin",
+    "General settings" : "Opsjonet e Pergjithshme",
     "Download" : "Shkarko",
     "Send email" : "Dërgo email",
-    "Groups" : "Grupe",
-    "Group name" : "Emër grupi",
     "Circles" : "Rrethet",
     "Create a new circle" : "Krijo një rreth të ri",
     "Rename" : "Riemëro",
