@@ -26,7 +26,6 @@ namespace OCA\Contacts\Service\Social;
 use OCP\Http\Client\IClientService;
 
 class MastodonProvider implements ISocialProvider {
-
 	/** @var IClientService */
 	private $httpClient;
 
@@ -106,7 +105,7 @@ class MastodonProvider implements ISocialProvider {
 						try {
 							[$masto_user, $masto_server] = $masto_user_server;
 							# search for user on Mastodon
-							$search = $masto_server . '/api/v2/search?q=' . $masto_user;
+							$search = $masto_server . '/api/v2/search?q=' . $masto_user . '@' . parse_url($masto_server)["host"];
 							$result = $this->httpClient->get($search);
 							$jsonResult = json_decode($result->getBody());
 							# take first search result
